AutoGen Studio [Beta]Build Multi-Agent Apps

#

Search
Galleries1
All Galleries
Default Component Gallery
v1.0.0
11 components
1 day agodefault
Gallery items marked as default (
) are available in the builder by default.
Galleries
Default Component Gallery

# Default Component Gallery

A default gallery containing several teams and agents.

AutoGen Team

11 components
v1.0.0
human-in-loop
assistant
web agents
3 teams
autogen_agentchat.teams.RoundRobinGroupChat
Deafult Team

A single AssistantAgent (with a calculator tool) in a RoundRobinGroupChat team.

autogen_agentchat.teams.RoundRobinGroupChat
Human in the loop team

A single AssistantAgent and a UserProxyAgent in a RoundRobinGroupChat team.

autogen_agentchat.teams.SelectorGroupChat
Web Agent Team (Operator)

A group chat team that have participants takes turn to publish a message to all, using a ChatCompletion model to select the next speaker after eac...

4 agents
autogen_agentchat.agents.AssistantAgent
AssistantAgent

An agent that provides assistance with tool use.

autogen_ext.agents.web_surfer.MultimodalWebSurfer
MultimodalWebSurfer

MultimodalWebSurfer is a multimodal agent that acts as a web surfer that can search the web and visit web pages.

autogen_agentchat.agents.AssistantAgent
AssistantAgent

An agent that provides assistance with tool use.

autogen_agentchat.agents.UserProxyAgent
UserProxyAgent

An agent that can represent a human user through an input function.

1 tool
autogen_core.tools.FunctionTool
FunctionTool

Create custom tools by wrapping standard Python functions.

3 models
autogen_ext.models.openai.OpenAIChatCompletionClient
OpenAIChatCompletionClient

Chat completion client for OpenAI hosted models.

autogen_ext.models.openai.OpenAIChatCompletionClient
Mistral-7B vllm

Example on how to use the OpenAIChatCopletionClient with local models (Ollama, vllm etc).

autogen_ext.models.openai.OpenAIChatCompletionClient
OpenAIChatCompletionClient

Chat completion client for OpenAI hosted models.

3 terminations
autogen_agentchat.conditions.TextMentionTermination
TextMentionTermination

Terminate the conversation if a specific text is mentioned.

autogen_agentchat.conditions.MaxMessageTermination
MaxMessageTermination

Terminate the conversation after a maximum number of messages have been exchanged.

autogen_agentchat.base.OrTerminationCondition
OrTerminationCondition
Maintained by the AutoGen Team.